Projects per language — Python interface to GnuCash documents 0.15.0 documentation

# Projects per language

This page lists all projects found by searching ‘gnucash’ on github (generated on 2017-10-08 20:52:39) excluding mirrors of the gnucash repository. Projects with a ‘*’ are projectsthat have not been updated since 12 months.

Language | # of projects | # of projects updated in last 12 months
--- | --- | ---
Python | 94 | 45
Unknown | 30 | 13
Perl | 26 | 11
Shell | 23 | 10
JavaScript | 18 | 9
Java | 26 | 8
Ruby | 12 | 7
PHP | 12 | 4
Scheme | 13 | 4
Go | 3 | 2
HTML | 4 | 2
Perl 6 | 2 | 2
C++ | 2 | 1
Jupyter Notebook | 3 | 1
R | 2 | 1
SQLPL | 1 | 1
Scala | 3 | 1
Swift | 1 | 1
Tcl | 1 | 1
TypeScript | 1 | 1
Visual Basic | 1 | 1
XSLT | 1 | 1
Awk | 1 | 0
C | 2 | 0
C# | 4 | 0
CoffeeScript | 1 | 0
Cucumber | 1 | 0
Diff | 1 | 0
F# | 1 | 0
Gettext Catalog | 1 | 0
Groovy | 1 | 0
Haskell | 2 | 0
PLSQL | 1 | 0
Perl6 | 1 | 0

## Python

* AceMoney-to-GnuCash by lowvoltage (last updated on 2015-01-11)
  A quick and dirty script to convert an AceMoney .XML into a GnuCash .XML
* alchemy by zmoog (last updated on 2016-05-08)
  A very simple Gnucash-inspired web application
BankCSVtoQif by niknow (last updated on 2017-02-07)
  Converts csv files from a bank to qif and replaces descriptions and target accounts according to predefined customizable rules along the way. Intended to work as a tool for gnucash.
django-openbudget by evandavey (last updated on 2017-01-20)
  Simple django-based personal budgeting app that sources data from GNUCash sqlite data files
* DnbNor2qif by djiti (last updated on 2013-08-26)
  Turning DnbNor CSV files into GNUCash-compatible QIF files
* dropcopy by juniorbl (last updated on 2015-10-25)
  A simple tool for GNOME to copy a given GnuCash file to a local dropbox directory whenever it is saved.
edoBank2Qif by engdan77 (last updated on 2017-08-18)
  Program for processing XML/XLS bank account exports into QIF-format supported by e.g. GnuCash developed in Python
* financial_forecast by skullspace (last updated on 2016-02-06)
  A script to take in our Gnucash books and output a CSV with some historical and forecasted data
* flux by marcotmarcot (last updated on 2015-04-23)
  Create a monthly flux report from a gnucash file
* gcconv by AloisMahdal (last updated on 2016-08-01)
  GnuCash import helper
gcimport by nblock (last updated on 2017-05-29)
  Convert various input files (csv, txt) to csv files that can be easily parsed with GnuCash.
gcinvoice by ngiger (last updated on 2017-04-06)
  GnuCash to Lates (see http://www.smoerz.org/gcinvoice/) + my personal templates
* gnc_budget_scroll by mateuszzz88 (last updated on 2016-09-18)
  This is a converter for gnucash bugdet report. It will create html with the same content, but table will be scrollable in such way, that headers (date, account name) are visible
* gnc_privat24 by gentoo90 (last updated on 2015-03-29)
  Imports Privat24 statements to Gnucash book
* gnucash-account2template by EvansMike (last updated on 2015-09-03)
  Make a GnuCash account template from an exported account
gnucash-bridge by dbellettini (last updated on 2017-02-18)
  Expose GnuCash as a microservice
* gnucash-budgerow- by dlex (last updated on 2016-02-05)
  Predictive budgeter for GnuCash
gnucash-budget by chrisbrasington (last updated on 2017-01-06)
  Minimalist budget reporting.
gnucash-categorizer by seddonym (last updated on 2017-04-14)
  (No description available)
* gnucash-cfdi by sebastianavina (last updated on 2016-09-09)
  Proyecto que timbra facturas de gnucash por medio de facturacion moderna.
* gnucash-expense-report by QuLogic (last updated on 2015-01-29)
  (No description available)
gnucash-fiximports by sandeepmukherjee (last updated on 2017-01-22)
  Change target accounts of imported gnucash transactions
gnucash-fiximports by HappyPeng2x (last updated on 2017-09-24)
  Additional developments on the original gnucash-fiximports
gnucash-import by manzato (last updated on 2017-09-03)
  Imports transactions from a CSV file and places them to the appropriate account depending on a set of rules
* gnucash-importers by rtucker (last updated on 2016-07-01)
  gnucash importer scripts for Interlock Rochester financial foo
gnucash-latex by mwellnitz (last updated on 2017-09-27)
  Create good looking invoices for gnucash using latex and python
gnucash-latex-koma by jappeace (last updated on 2017-02-18)
  Create good looking invoices for gnucash using latex/koma and python
* gnucash-ofx-brokerage by 7max (last updated on 2013-10-20)
  GnuCash OFX importer that handles brokerages, ie stocks, mutual funds, optios
gnucash-ofx-export by hoffie (last updated on 2017-05-25)
  Selectively export GnuCash transactions into OFX
* gnucash-pyquotehist by tfree87 (last updated on 2015-07-26)
  A simple python script which imports historical price quotes from yahoo into Gnucash via the command line without the need for Perl Finance::QuoteHist. Based on Peter Holtermann’s quotes_hist script
* Gnucash-Python-Example by petarkabashki (last updated on 2015-12-02)
  Example python script for importing data into Gnucash
* gnucash-python-free by tbhartman (last updated on 2014-08-23)
  (No description available)
* GNUCash-Python-Scripts by relyt29 (last updated on 2016-07-04)
  various python scripts to add to gnucash functionality
gnucash-qif-import by hjacobs (last updated on 2017-09-24)
  GnuCash Python helper script to import transactions from QIF text files into GnuCash’s own file format
* gnucash-reporting by MeerkatLabs (last updated on 2015-10-30)
  Simple reporting framework for fetching data out of gnucash files for display in a viewer.
gnucash-rest by loftx (last updated on 2017-02-05)
  A Python based REST framework for the Gnucash accounting application
GNUCash-scripts by spartha80 (last updated on 2016-12-22)
  Simple Python scripts to convert Bank statements to QIF format
* gnucash-society by hendrikvanantwerpen (last updated on 2013-11-02)
  Support application for societies based on GnuCash
gnucash-stock-portfolio by hjacobs (last updated on 2017-08-19)
  GnuCash Python utilities to manage a stock portfolio
gnucash-to-beancount by henriquebastos (last updated on 2017-03-12)
  Gnucash to Beancount Converter.
* gnucash-tools by dahnielson (last updated on 2013-11-30)
  Tools for working with GnuCash
* gnucash-tools by yanivmo (last updated on 2016-03-16)
  GnuCash interoperability scripts
* gnucash-tools by cnuahs (last updated on 2016-07-26)
  Command line tools for use with Gnucash (http://gnucash.org/).
* gnucash-toolset by cirrax (last updated on 2015-03-04)
  Access and manipulate gnucash data.
* gnucash-util by bstpierre (last updated on 2015-02-16)
  Utility scripts using GnuCash python bindings
gnucash-utilities by sdementen (last updated on 2016-12-22)
  Set of python scripts to work with GnuCash books
* gnucash-utils by AndreasHeger (last updated on 2015-05-20)
  utility scripts for gnucash
* gnucash-xml-split by fefe982 (last updated on 2014-08-26)
  Split GnuCash XML files into files containing transaction in a certain period (e.g. a year)
* gnucash2iif by pawl (last updated on 2013-08-18)
  Converts a Gnucash general ledger to an IIF file (for quickbooks)
gnucash_autobudget by rmoehn (last updated on 2017-03-06)
  Automatically adjust GnuCash transactions for envelope budgeting (discontinued)
* gnucash_balance_report by tbhartman (last updated on 2014-07-24)
  get balance report from gnucash file
gnucash_budget by dschwen (last updated on 2017-01-22)
  Tools to work with a GnuCash database
gnucash_converter by boszkie (last updated on 2017-05-12)
  python script to convert rabobank (nl) csv format to gnuCash csv import format
* gnucash_django by RobFisher (last updated on 2014-04-09)
  GnuCash Web Interface using Django.
* gnucash_explorer by peap (last updated on 2014-04-27)
  Another option for exploring your gnucash database
* gnucash_exports by jjuanda (last updated on 2014-01-13)
  GnuCash export scripts into several DBs/file formats
* gnucash_lbb_amazon by elezar (last updated on 2015-12-28)
  Amazon Credit Card CSV pre-processor for GNUCash
* gnucash_ofx by gevious (last updated on 2015-03-26)
  Convert gnucash xml file to set of OFX files
gnucash_python by davidjo (last updated on 2016-10-31)
  gnucash report writing in python
* gnucash_scripts by vrih (last updated on 2013-09-10)
  (No description available)
* gnucashdjango by ugedo (last updated on 2016-07-04)
  (No description available)
* GnuCashImporter by sphaero (last updated on 2015-03-08)
  Simple console tool to import mt940 file and match transactions to GnuCash accounts
gnucashreconcile by seddonym (last updated on 2017-03-29)
  (No description available)
gnucashreport by partizand (last updated on 2017-05-15)
  Python library for get reports from GnuCash to xlsx files
GnucashReporting by sholly (last updated on 2017-06-27)
  Python/Flask backend for gnucash reports
* gnucashreports by youngchul (last updated on 2015-07-08)
  (No description available)
gnuCashTools by Walms (last updated on 2017-07-17)
  Just a few scripts to help manage my budget
gnucashxml by jorgenschaefer (last updated on 2017-02-05)
  New Maintainer, please use their repository
* hackerspace-gnucash by cvonkleist (last updated on 2015-01-06)
  Gainesville Hackerspace GnuCash scripts, etc.
importfindata by gregorias (last updated on 2017-06-25)
  Script that updates Polish investment fund quotes in a Gnucash file.
* ing2gnucash by hjmeijer (last updated on 2013-10-29)
  Converts downloaded ING (bank) transaction CSV files to GNUCash importable CSV
ing2qif by marijnvriens (last updated on 2017-10-07)
  Import ING bank statements and convert them to qif for importing into gnucash
ing2qif2 by tychobismeijer (last updated on 2017-03-13)
  Convert ING csv to QIF format for GnuCash
jeffs-gnucash-utils by n1ywb (last updated on 2016-12-13)
  Jeff Laughlin’s Python utilities for GnuCash. Includes HTML invoice generator.
koert by awesterb (last updated on 2017-03-19)
  Toolbox for the inspection of GnuCash (used by the financial control committee of Karpe Noktem).
* ledger2gnucash by forsetti (last updated on 2016-01-19)
  Simple python script to convert ledger-cli files to GnuCash
* masin by FelixAkk (last updated on 2013-12-28)
  A rework and GUI wrapping of the gcInvoice Python package for generating template based invoices from .gnucash data files.
* mbank2gnucash by h3xxx (last updated on 2014-10-16)
  mBank transactions history to GnuCash converter
* mcash by mpharrigan2 (last updated on 2015-07-06)
  Investigate GNUCash
Mint2GNUCash by alexevans91 (last updated on 2017-03-04)
  Converts transaction CSV file from Mint.com to a format that can be imported into GNU Cash.
mintcash by hiromu2000 (last updated on 2017-01-02)
  Transfer transactions from Mint.com to Gnucash
* NokiaCash by sunziping2016 (last updated on 2016-06-01)
  A GnuCash-like software on S60v3 developed by python
ofxstatement by kedder (last updated on 2017-09-26)
  Tool to convert proprietary bank statement to OFX format, suitable for importing to GnuCash.
piecash by sdementen (last updated on 2017-07-21)
  Pythonic interface to GnuCash SQL documents
PyBank by dougthor42 (last updated on 2017-03-09)
  Personal accounting software. Alternative to the likes of Quicken, iBank, Mint.com, and GnuCash
pygnclib by tdf (last updated on 2016-12-04)
  Pyxb-based read and write support for GnuCash XML files
pygnucash by MatzeB (last updated on 2017-09-03)
  Python code to read gnucash 2.6 sqlite3 files
qifqif by Kraymer (last updated on 2017-09-29)
  Enrich your .QIF files with categories
rabobank-gnucash-converter by LvanWissen (last updated on 2017-01-26)
  (No description available)
scripts by frinkelpi (last updated on 2017-05-12)
  Collection of Python scripts
text-messaging-to-gnucash by chrisbrasington (last updated on 2016-12-05)
  Create transactions via commandline text-messaging to gnucash sqlite database.
* Timetracker-to-Gnucash-Invoice by EvansMike (last updated on 2015-02-06)
  Takes Anuko Timetracker data and creates an Invoice in GnuCash
* tws-gnucash by timwswanson (last updated on 2014-03-29)
  (No description available)
* visa-parser by pguridi (last updated on 2015-11-04)
  A parser for the Visa pdf bill from www.visa.com.ar, useful for CSV import in Gnucash.

## Awk

* ibank2qif by tomszilagyi (last updated on 2015-04-01)
  Bank account transactions into GnuCash

## C

* gnucash-aqplus by jhs-s (last updated on 2014-05-02)
  Usually contains some fixes for aqbanking for GnuCash
* gnucash-svn by cstim (last updated on 2014-04-14)
  another clone of gnucash, but this time not using github’s clone, and therefore keeping the svn metadata

## C#

* FinanceWeb by elohmeier (last updated on 2016-07-09)
  C#/.NET OData Adapter for reading GnuCash Databases with MSFT Excel
* gnucash2ledger-cli by marek-g (last updated on 2014-08-05)
  Gnucash (general ledger html report) to ledger-cli converter.
* GnuCashParser by nikitazu (last updated on 2015-06-23)
  .Net parser for GnuCash files format
* GnuCashSharp by rstarkov (last updated on 2016-10-05)
  A library for reading data from GnuCash XML files.

## C++

* gnucash-butchered by iulianu (last updated on 2015-12-04)
  My own butchered version of Gnucash
UnderBudget by vimofthevine (last updated on 2016-11-22)
  Advanced personal budget analysis application that integrates with GnuCash, Quicken, mint.com, etc.

## CoffeeScript

* gnucash-viewer by phjardas (last updated on 2016-02-15)
  (No description available)

## Cucumber

* commerzbank-csv4gnucash by kisp (last updated on 2016-04-25)
  Tweak CSV exports from commerzbank for importing into GnuCash.

## Diff

* GnuCash-Windows-Fixes by theochino (last updated on 2015-03-19)
  Pieces needed to Compile Gnu Cash on a Windows machine … http://wiki.gnucash.org/wiki/User:Bilkusg

## F#

* gnucash-tools by cantsin (last updated on 2015-06-01)
  (No description available)

## Gettext Catalog

* gnucash-el by pgaval (last updated on 2015-03-14)
  Automatically exported from code.google.com/p/gnucash-el

## Go

gnucash-viewer by mmbros (last updated on 2016-12-19)
  A gnucash file viewer
gnucash-viewer-old by mmbros (last updated on 2016-12-19)
  (No description available)
* gocash by remyoudompheng (last updated on 2016-01-20)
  gocash is a personal accounting interface similar to gnucash

## Groovy

* Zio-Antunello by masokotanga (last updated on 2013-10-13)
  un gnucash online (?)

## HTML

* BackupGnuCashLinux by goodvibes2 (last updated on 2016-06-02)
  Backup GnuCash for Linux (using openjdk + openjfx)
gnucash-htdocs by Gnucash (last updated on 2017-08-16)
  GnuCash website.
* gnucash-jp by omoshetech (last updated on 2016-10-07)
  (No description available)
gnucashkr.github.io by GnucashKr (last updated on 2017-05-06)
  gnucashkr.github.io 홈페이지 소스

## Haskell

* hGnucash by pharaun (last updated on 2016-01-18)
  Haskell xml library for parsing the gnucash file format
* hs-gnucash by knupfer (last updated on 2015-07-07)
  Haskell library to work with gnucash

## Java

accounting by milanogc (last updated on 2017-01-23)
  This project is an attempt to create a GnuCash like system, i.e. it adopts the double entry bookkeeping accounting system, for the management of personal finances.
androidcash by mbarbon (last updated on 2017-05-23)
  Simple Android GnuCash companion
barx by pgiu (last updated on 2017-06-20)
  Exportador de la información del estado de cuenta de Banco Galicia a CSV/QIF para usar en MoneyManagerEx, GnuCash, etc.
* barxm by pgiu (last updated on 2015-03-05)
  Exportador de la información del estado de cuenta de Banco Galicia a CSV/QIF para usar en MoneyManagerEx, GnuCash, etc.
* BudgetReportGnuCash by martinlong1978 (last updated on 2014-04-23)
  Jasper Budget Report for GnuCash
* convert-ingcsv-to-gnucash by jonaskoperdraat (last updated on 2016-06-16)
  Application to convert csv export from ING to a format GnuCash can import
* gcchart by jhogan (last updated on 2015-06-19)
  An website for reading GnuCash datasources and creating charts written in Java.
* gnc4a by bwduncan (last updated on 2014-11-22)
  GnuCash Companion for Android is an mobile application for devices running Google’s Android operating system, which will enable the users of GnuCash to do small things like adding a transaction or creating an invoice or expense voucher on the go.
* gnc4a by glennji (last updated on 2013-10-20)
  Gnucash for Android
* GncImport by fcuenca (last updated on 2016-07-27)
  GnuCash transaction import tool
* GncXmlLib by fcuenca (last updated on 2015-11-12)
  A small library to manipulate GnuCash data in XML format
* GnuCash-2.6.5-importer by jan438 (last updated on 2015-02-02)
  (No description available)
gnucash-android by codinguser (last updated on 2017-10-08)
  Gnucash for Android mobile companion application.
gnucash-android-master by lucifa7 (last updated on 2017-07-14)
  (No description available)
gnucash-merge by pnemonic78 (last updated on 2017-05-10)
  Merge two gnucash XML files.
* GnuCashBudgetReport by bvitale (last updated on 2015-02-16)
  A budget report for GnuCash data that is stored in MySQL.
* gnucashMobile by nhrdl (last updated on 2013-10-19)
  (No description available)
* GnuCashToQIF by davidkgerman (last updated on 2013-11-29)
  (No description available)
* GnuCashViewer by jrmcsoftware (last updated on 2016-01-12)
  GnuCash Viewer
* IngAusOfxFixLinux by goodvibes2 (last updated on 2016-07-29)
  ING Australia OFX Fix for Linux - Fix OFX file before importing into GnuCash
* javacash by nhrdl (last updated on 2013-08-09)
  Yet another implementation of gnucash in Java
jcash by Ccook (last updated on 2017-01-28)
  The missing Java API for GNUCash
* jgnucashlib by tdf (last updated on 2013-09-28)
  jGnucashLib - a java access to GnuCash files
Maakboekingen by zwijze (last updated on 2016-12-10)
  Maakboekingen in gnucash
* nordea-to-gnucash by mohamedamer (last updated on 2013-12-08)
  (No description available)
* workspace_gnucash by won21kr1 (last updated on 2014-04-16)
  (No description available)

## JavaScript

* BackupGnuCashWin by goodvibes2 (last updated on 2016-05-31)
  Backup GnuCash for Windows (using javafx)
* bcqif by hugozap (last updated on 2015-09-23)
  Script simple para generar archivos QIF a partir de archivos .txt exportados desde Bancolombia y poder cargar los registros a programas como GnuCash
* finance_dashboard by manicolosi (last updated on 2015-05-20)
  A dashing dashboard to show financial information from GnuCash
gnu-docs by mtuchi (last updated on 2017-06-18)

  sparkles: | Awesome GnuCash Docs

gnucash-django by nylen (last updated on 2017-09-06)
  Simple Web frontend for GnuCash, using Django
* gnucash-ext by matthewbednarski (last updated on 2015-05-30)
  (No description available)
gnucash-price-importer by cortopy (last updated on 2017-07-09)
  Script for importing historic currency prices into gnucash
gnucash-reporter by AaronLenoir (last updated on 2017-02-17)
  Visualizes some reports on GnuCash data.
* gnucash-reporting-view by MeerkatLabs (last updated on 2015-09-30)
  Angular JS Based viewer for gnucash-reports
* gnucash-viewer by drjeep (last updated on 2014-05-02)
  Web viewer for Gnucash using Python/Flask
* gnucash-web by mrkrstphr (last updated on 2014-01-29)
  (No description available)
GnucashReportingNVD3 by sholly (last updated on 2017-06-27)
  NVD3 frontend/playground for gnucash reporting..
googcash by crazyh (last updated on 2017-02-06)
  Simple Google Sheets replacement for GnuCash
* IngAusOfxFixWin by goodvibes2 (last updated on 2016-07-29)
  ING Australia OFX Fix for Windows - Fix OFX file before importing into GnuCash
profitcash-restful by TheProfitwareGroup (last updated on 2017-07-11)
  [DEPRECATED] ProfitCash-RESTful is a RESTful service providing accounts and transaction information based on imported from GnuCash into MongoDB data.
qif-converter by math1985 (last updated on 2017-10-07)
  Converts CSV files from ING (Netherlands) and BCEE (Luxembourg) into QIF files. Suitable for GnuCash.
remotegnucash by justinhunt1223 (last updated on 2016-12-03)
  Remote GnuCash
* skilap by sergeyksv (last updated on 2016-08-20)
  Personal online applications, GnuCash clone and others

## Jupyter Notebook

* gnucash-playground by nlzimmerman (last updated on 2016-08-15)
  Just playing around with OFX and gnucash files; I am presumably the only person who cares about this sort of things.
* gnucash_analysis by prattmic (last updated on 2016-06-02)
  Analyze GnuCash data with Pandas
py-gnucash by ihkihk (last updated on 2017-05-10)
  Python scripts for analysis of gnucash database

## PHP

* buchungen by jungepiraten (last updated on 2016-09-12)
  Webinterface für gnucash-Datenbank mit Funktion zum Verifizieren von Buchungen
cash-manager by jUnG3 (last updated on 2017-01-14)
  (No description available)
* cashonline-php-server by okovalov (last updated on 2014-10-07)
  Backend part for cashonline project (clone of gnucash)
gnucash-eloquent by b3it (last updated on 2016-11-09)
  Laravel Eloquent Models for the GnuCash MySQL Backend
* gnucash-laravel by xstat (last updated on 2015-12-21)
  (No description available)
* gnucash-php by cebe (last updated on 2016-04-02)
  A library for reading gnucash XML format in PHP
gnucash-reports by xstat (last updated on 2017-07-30)
  (No description available)
* gnucash-tools by cccmzwi (last updated on 2015-02-16)
  Convert your onlinebanking-export (CSV) to a neatly pre-categorized QIF-File which can be imported in Quicken or Gnucash
* gnucash.cakephp by claudineimatos (last updated on 2014-06-25)
  (No description available)
* gnucashreports by pedroabel (last updated on 2015-02-16)
  Set of custom reports that I use for my personal finances. To see the reports working on a sample database, check the website http://gnucashreports.comuf.com/ ATTENTION: many problems yet. Many bugs that did not happen in my computer happened in this sample server.
* php-gnucash by mrkrstphr (last updated on 2014-01-01)
  (No description available)
ThinkopenAt.Gnucash by kraftb (last updated on 2017-04-07)
  A TYPO3 Flow package which allows to interface the Gnucash book keeping application

## PLSQL

* gnucash-mysql-additions by ohingardail (last updated on 2016-07-20)
  Custom MySql functions to add useful functions to GnuCash

## Perl

bsestocks by poomalairaj (last updated on 2017-06-07)
  Perl module to fetch live price from Bombay Stock Exchange (BSE) for Gnucash Finance
budgetProgram by Beahmer89 (last updated on 2016-10-23)
  Converts GNUCash programs xml output to csv file to see monthly/yearly spending habits
Finance–Quote–YahooJapan by LiosK (last updated on 2017-01-18)
  Finance::Quote::YahooJapan - A Perl module that enables GnuCash to get quotes of Japanese stocks and mutual funds from Yahoo! Finance JAPAN.
finance-bomse by abhijit86k (last updated on 2017-09-11)
  A Perl module for fetching quotes for Indian stocks, intended for use with gnucash
finance-quote-brazil by romuloceccon (last updated on 2017-06-12)
  Gnucash/Finance::Quote modules to fetch prices of Brazilian bonds and mutual funds
FinanceQuoteBr by ailtonljr (last updated on 2017-09-08)
  Perl Finance Quote modules for Brazilian market. Original files from https://lists.gnucash.org/pipermail/gnucash-br/2016-November/000535.html
* gc2latex by wertarbyte (last updated on 2015-02-16)
  create pretty Gnucash invoices with LaTeX and Perl
* GnuCash-Branch by LiosK (last updated on 2015-04-26)
  GnuCash::Branch - Utilities to implement branch accounting with GnuCash.
* gnucash-extensions by tomason (last updated on 2016-09-28)
  (No description available)
* gnucash-importer by AloisMahdal (last updated on 2014-09-09)
  Import CSV data from arbitrary bank format to CSV acceptable by GnuCash
* gnucash-monthly-budget-report by mhodapp (last updated on 2015-03-01)
  perl program to generate monthly budget reports
* GnuCash-MySQL by theochino (last updated on 2015-03-18)
  A MySQL module to Gnu Cash
gnucash-perl by goblin (last updated on 2016-11-01)
  Perl modules for reading and writing the Gnucash XML file
gnucash-quote-sources by tjol (last updated on 2017-04-23)
  Some useful methods to fetch market price data for GnuCash
* GnuCash-SQLite by hoekit (last updated on 2015-01-25)
  A perl module to access GnuCash SQLite files.
* GnuCash-SQLite by gitpan (last updated on 2015-01-08)
  Read-only release history for GnuCash-SQLite
* gnucash-summarizer by Nazrax (last updated on 2016-05-06)
  (No description available)
gnucash2mysql by xaprb (last updated on 2017-01-13)
  Gnucash to MySQL export script.
gnucash2mysql_extras by hmackiernan (last updated on 2016-12-02)
  Extra scripts and bits for gnucash2mysql
* gnuCash_Quote by z-Wind (last updated on 2016-01-06)
  modify perlsitelibFinanceQuote.pm
* MoneyDance-GnuCash-Importer by ets (last updated on 2016-02-27)
  Script to convert GnuCash data into a native MoneyDance XML file format
* Paypal-csv-to-qif-converter by sonologic (last updated on 2014-09-08)
  Converts paypal .csv to qif for importing in gnucash
* perl-gnucash-reader by hoekit (last updated on 2014-09-09)
  (No description available)
PerlFinanceQuoteBloomberg by alex314159 (last updated on 2017-09-26)
  Bloomberg module for the Perl Finance::Quote module (used in particular by GnuCash)
* query_gnucash_db by hmackiernan (last updated on 2016-08-20)
  Perl script to query a MySQL db created by the ‘gnucash2mysql’ script
* tikzdipa by vimdude (last updated on 2014-12-21)
  GnuCash online quote source using Yahoo api

## Perl 6

gnucashfinancequote by vimdude (last updated on 2017-08-19)
  Gnucash quote using Google Finance
MumbaiStock by geetuvaswani (last updated on 2017-08-25)
  MumbaiStock - A perl module for Finance::Quotes that fetches the day end price list from Bombay Stock Exchange into GnuCash

## Perl6

* perl6-gnucash by eikef (last updated on 2016-08-14)
  Use gnucash library from Perl 6

## R

* GnuCashConverter by ms32035 (last updated on 2015-09-12)
  R package to convert transaction history files from Polish banks to GnuCash importable CSVs
ShinyBudgetAnalysis by paulheider (last updated on 2017-03-08)
  A Shiny app (R-based dashboard) that gives insight into your GnuCash budget habits over time.

## Ruby

* accounting by freegeek-pdx (last updated on 2013-12-04)
  accounting utilities for xtuple import and allocation in xtuple and gnucash
arges by isimluk (last updated on 2017-01-15)
  Calc roe from gnucash transaction log
cnab2ofx by abinoam (last updated on 2017-02-14)
  CNAB240 to OFX conversion script
dnbnor2qif by kentdahl (last updated on 2017-01-04)
  dnbnor2qif is a simple tool to help integrate data from the DnBNOR online bank monthly transcripts (“kontoutskrift”) to a QIF accepting financial program, i.e. GnuCash.
gnucash-invoice by ixti (last updated on 2016-11-05)
  Easy to use invoice printer for GnuCash.
* gnucash-rb by vbatts (last updated on 2013-09-18)
  Ruby access to Gnucash SQL database
gnucash2bmd by ngiger (last updated on 2017-05-22)
  Convert GnuCash CSV files into CSV which can be read by http://www.bmd.com/
* gnucash2ledger by xaviershay (last updated on 2015-03-06)
  Convert GnuCash files to a format supported by the ledger command line application
* gnucash_export by alibby (last updated on 2013-12-01)
  Export gnucash data to sqlite/ csv
* nyancash by hanazuki (last updated on 2016-09-28)
  Ruby to GnuCash database binding
ruby-gnucash by holtrop (last updated on 2017-10-06)
  Ruby library for extracting data from GnuCash data files
vfwcash by salex (last updated on 2017-05-01)
  A Ruby CLI application that produces PDF reports from GnuCash

## SQLPL

gnucash-tools by schoettl (last updated on 2017-02-21)
  Collection of tools to work with GnuCash efficiently

## Scala

* gnucash-quotes by akorneev (last updated on 2014-12-20)
  (No description available)
* gnucash-stuff by crankydillo (last updated on 2014-01-18)
  (No description available)
GnuCashExtractor by Winbee (last updated on 2017-06-04)
  Extract data from gnuCash and copy it into an open document spreadsheet

## Scheme

* gc-decl-reports by yawaramin (last updated on 2014-02-09)
  GnuCash declarative reports
gnucash-account-balance-chart by timabell (last updated on 2016-10-10)
  account balance line chart for gnucash
* gnucash-custom-reports by BenBergman (last updated on 2016-04-01)
  (No description available)
gnucash-multicolumn by christopherlam (last updated on 2017-04-03)
  Advanced date and text filtering and multicolumn reports
* gnucash-reports by trailbound (last updated on 2015-11-05)
  Custom set of gnucash reports, currently in development.
gnucash-reports by jaminh (last updated on 2017-04-04)
  Reports for personal finance using gnucash
* gnucash-reports by dschwen (last updated on 2016-01-27)
  Custom reports for Gnucash
* gnucash-reports by cnuahs (last updated on 2015-12-28)
  Custom reports for use with GnuCash (http://gnucash.org/).
gnucash-reports by wentzel (last updated on 2016-10-26)
  Some nice reports for GnuCash
* gnucash-statement-table by waldeinburg (last updated on 2016-01-13)
  GnuCash report with cash flow over time
* gnucashportable by GordCaswell (last updated on 2016-01-12)
  GnuCash packaged in PortableApps.com Format
* GnuCashReports by wlcasper (last updated on 2015-07-19)
  Custom Reports for GnuCash
* ibr-gnc-module by ErwinRieger (last updated on 2016-04-04)
  GnuCash Erweiterungen für deutsche Buchhaltung

## Shell

AccountsConvertToGnucash by tontako (last updated on 2016-12-23)
  Convert Kakeibo(Android Application) CSV exports to QIF format (usable by GnuCash and others)
* archlinux-gnucash-latest by nengxu (last updated on 2015-03-31)
  Archlinux AUR package building scripts for latest Gnucash
docker-gnucash-novnc by bertlorenz (last updated on 2017-08-21)
  (No description available)
* gnucash-csv-import by thomasramapuram (last updated on 2016-08-08)
  (No description available)
* gnucash-cubes by leo90skk (last updated on 2016-09-04)
  A OLAP database model for a mysql based GnuCash installation.
* gnucash-devel by aur-archive (last updated on 2015-08-15)
  (No description available)
gnucash-docker by limitedAtonement (last updated on 2017-01-27)
  docker image for repeatable gnucash builds.
* gnucash-docs by aur-archive (last updated on 2015-08-15)
  (No description available)
gnucash-docs-old by yasuakit (last updated on 2017-07-02)
  Manual and User Guide for Gnucash, the open-source accounting program
* gnucash-hbci by aur-archive (last updated on 2015-08-15)
  (No description available)
gnucash-jz-snap by jacobzimmermann (last updated on 2017-08-30)
  (No description available)
* gnucash-on-fedora-copr by Gnucash (last updated on 2016-05-31)
  A set of build scripts geared towards creating rpm packages for gnucash and gnucash-docs on Fedora’s Copr infrastructure. It’s currently used to build nightly rpm packages for the maint and master branches intended for testing changes since the last release..
gnucash-on-osx by jralls (last updated on 2017-05-11)
  Build GnuCash on OSX without X11
gnucash-on-osx by Gnucash (last updated on 2017-06-16)
  Gtk-OSX moduleset, gtk-mac-bundler bundles, and ancillary files for creating GnuCash OSX Application Bundle.
gnucash-on-windows by Gnucash (last updated on 2017-09-26)
  Support scripts to build gnucash for Windows using mingw32.
gnucash-on-windows by gjanssens (last updated on 2017-01-26)
  Support scripts to build gnucash for Windows using mingw32.
* gnucash-python by aur-archive (last updated on 2015-08-15)
  (No description available)
* gnucash-svn by aur-archive (last updated on 2015-08-15)
  (No description available)
gnucash-util-jp by mikkun (last updated on 2016-10-23)
  日本の商慣習下でGnuCashを使うためのツール
* gnucash.SlackBuild by botzkobg (last updated on 2015-04-02)
  SlackBuild script to compile GnuCash
* LittleBudget by kstripp (last updated on 2016-09-12)
  Little Budget Tool for GNUCash
* nordea2ofx by nsrosenqvist (last updated on 2014-10-24)
  A quick implementation of a converter between Nordea’s CSV export to OFX so that it can be imported into various applications, such as Homebank or GnuCash. Only supporting Swedish and my edge cases, please consider improving the script and send a pull request for the changes.
* TW5-GNUCash-Assistant by JulioCantarero (last updated on 2016-03-12)
  A custom edition of TiddlyWiki5 designed to collect financial information from your banks and export them in QIF format

## Swift

cash by cjwirth (last updated on 2017-06-26)
  iOS companion app for GnuCash

## Tcl

pycash by EvansMike (last updated on 2017-06-12)
  Some Python utilites that GnuCash users may find useful.

## TypeScript

web-cash by nulldev07 (last updated on 2017-05-21)
  Web version of GnuCash

## Visual Basic

OneClickToQif by OneClickToQif (last updated on 2017-09-23)
  OneClickToQIF consists of a set of templates and macros, which are used to export data from your spreadsheets to QIF format, as used by programs such as GnuCash, Money and Quicken. You can use the templates as provided, or adapt your own spreadsheet, so your data is automatically exported to QIF with a single click.

## XSLT

gnucash-docs by Gnucash (last updated on 2017-08-20)
  Documentation for GnuCash Accounting Program.

## Unknown

* accounting by communotey (last updated on 2016-10-05)

  moneybag: | Accounting for Communote, using GNUCash

* accounts by sjtug (last updated on 2016-09-25)
  Accounts of SJTUG in GNUCash Format
* an-gnucash by wanjing (last updated on 2013-01-11)
  android app for gnucash
ansible-role-gnucash by wtanaka (last updated on 2017-07-08)
  Ansible role for installing gnucash
* CICtoGNUcash by jbtruffault (last updated on 2016-06-15)
  (No description available)
ComptaTest by palric (last updated on 2017-05-05)
  Exercices programmation python/panda: importation de fichiers comptas bancaires, formatage et importation dans GnuCash
CPA-006-Asap-Cheques by dougransom (last updated on 2017-09-25)
  Gnucash Check Configurations to print on Canadian Cheques from ASAP Cheques.
docker-gnucash by mbessler (last updated on 2017-10-01)
  Containerized GnuCash
docker-gnucash by mhitchens (last updated on 2017-04-16)
  GnuCash running via X11 over SSH
docker-mobile-gnucash by au-phiware (last updated on 2016-12-18)
  Docker containers for justinhunt1223/mobilegnucash
* GCtranslate by AshokR (last updated on 2016-09-27)
  GnuCash Translation
* GnuCash-3part-check by agh1 (last updated on 2013-10-17)
  A 3-part check format for GnuCash
* gnucash-api by jjuanda (last updated on 2014-02-02)
  REST APIs for GnuCash files
* gnucash-auditfile by vylum (last updated on 2016-02-05)
  Creates a dutch Auditfile for tax purposes from a gnuCash datafile.
gnucash-compose by daveyb (last updated on 2017-03-11)
  docker-compose file(s) to bring up local gnucash cluster
* gnucash-data by anshprat (last updated on 2015-06-02)
  data files for my gnucash encrypted with gpg
* gnucash-docs by cygwinports (last updated on 2016-03-07)
  Cygwin gnucash-docs packaging
* gnucash-export by deonbredenhann (last updated on 2014-06-19)
  Export GnuCash to csv
gnucash-guide-gitbook by codesmythe (last updated on 2017-06-02)
  The GnuCash Tutorial and Concept Guide, converted to Asciidoc for use in GitBook
gnucash-queries by g2010a (last updated on 2016-10-18)
  Queries to extract data from Gnucash’s database
* gnucash-rest by mhitchens (last updated on 2014-05-03)
  A Spring Data/Spring REST interface to a gnucash data file
* gnucash-web by djbrown (last updated on 2016-01-01)
  (No description available)
gnucash_auto by torchtarget (last updated on 2017-08-16)
  A simple transaction importer for Gnucash
* gnucashweb by AndersonLira (last updated on 2015-11-01)
  Web App Based on Grails like gnucash desktop
knab-gnucash-converter by bkrijg (last updated on 2017-05-03)
  A python script for converting KNAB bankstatement information files into a suitable gnucash csv import file
mint2gnucash by SAL-e (last updated on 2017-04-05)
  Use mint.com together with GnuCash.
* nordea-csv2qif by martinolsen (last updated on 2014-06-11)
  Convert Nordea CSV exports to QIF format (usable by GnuCash and others)
org.gnucash.GnuCash by flathub (last updated on 2017-07-06)
  (No description available)
* PayPalConvert by rowantree (last updated on 2015-11-04)
  Convert PayPal csv files to qif for loading into GnuCash
* rabo2qif by milovanderlinden (last updated on 2015-09-03)
  export mut.txt to qif for gnucash